@@ -9,6 +9,7 @@ import json
 import shutil
 import logging
 import datetime
+import platform
 import traceback
 from tools import AdbCommand
 from os.path import join, exists
@@ -46,6 +47,8 @@ def _findExetuable(program):
     return the absolute path of executable program if the program available.
     else raise Exception.
     '''
+    if platform.system() == "Windows":
+        return program
     program_path, program_name = os.path.split(program)
     if program_path:
         if _isExecutable(program):
@@ -58,6 +61,13 @@ def _findExetuable(program):
                 return exe_file
     raise Exception(LOCATION_NOT_FOUND_EXCEPTION % program)
 
+def _wraptime(dt):
+    sysstr = platform.system()
+    if(sysstr == "Windows"):
+        return str(dt).replace(':', '.')
+    else:
+        return str(dt)
+
 def _time():
     '''
     time stamp format
@@ -84,7 +94,7 @@ def _save(path, types='fail'):
         if serial:
             if types == 'fail':
                 AdbCommand('%s -s %s shell screencap /sdcard/%s' % (bridge ,serial, FAILURE_SNAPSHOT_NAME)).run()
-                AdbCommand('%s -s %s pull /sdcard/%s %s' % (bridge, serial, FAILURE_SNAPSHOT_NAME, path)).run()
+                AdbCommand('%s -s %s pull /sdcard/%s \"%s\"' % (bridge, serial, FAILURE_SNAPSHOT_NAME, path)).run()
             output = AdbCommand('%s -s %s logcat -v time -d' % (bridge, serial)).run()
             with open(join(path, LOG_FILE_NAME), 'w') as o:
                 o.write(output)
@@ -95,7 +105,7 @@ def _save(path, types='fail'):
         else:
             if types == 'fail':
                 AdbCommand('%s shell screencap /sdcard/%s' % (bridge, FAILURE_SNAPSHOT_NAME)).run()
-                AdbCommand('%s pull /sdcard/%s %s' % (bridge, FAILURE_SNAPSHOT_NAME, path)).run()
+                AdbCommand('%s pull /sdcard/%s \"%s\"' % (bridge, FAILURE_SNAPSHOT_NAME, path)).run()
             output = AdbCommand('%s logcat -v time -d ' % bridge).run()
             with open(join(path, LOG_FILE_NAME), 'w') as o:
                 o.write(output)
@@ -120,10 +130,10 @@ def _writeSSPIDToFile(path):
         times = '?'
         system_server_pid = '?'
         if serial:
-            system_server_pid = AdbCommand('%s -s %s shell ps | grep system_server' % (bridge, serial)).run().strip().split()[1]
+            system_server_pid = AdbCommand('%s -s %s shell \"ps | grep system_server\"' % (bridge, serial)).run().strip().split()[1]
             times = AdbCommand('%s -s %s shell date' % (bridge, serial)).run().strip()
         else:
-            system_server_pid = AdbCommand('%s shell ps | grep system_server' % bridge).run().strip().split()[1]
+            system_server_pid = AdbCommand('%s shell \"ps | grep system_server\"' % bridge).run().strip().split()[1]
             times = AdbCommand('%s shell date' % bridge).run().strip()
         pid_file = join(path, 'system_server_pid.txt')
         with open(pid_file, 'a') as f:
@@ -295,7 +305,7 @@ class FileOutputPlugin(nose.plugins.Plugin):
             self.test_start_time = datetime.datetime.now()
             self.conf.update({'test_start_time': str(self.test_start_time)})
         
-        self._report_path = _mkdir(join(join(self.opt.directory, 'report'), str(self.test_start_time).replace(' ', '_')))
+        self._report_path = _mkdir(join(join(self.opt.directory, 'report'), _wraptime(self.test_start_time).replace(' ', '_')))
         self._all_report_path = _mkdir(join(self._report_path, 'all'))
         #add 20140925
         self._pass_report_path = _mkdir(join(self._report_path, 'pass'))
@@ -317,7 +327,7 @@ class FileOutputPlugin(nose.plugins.Plugin):
         device.right_dir_path = join(join(join(os.getcwd(), test.id().split('.')[0]), 'pics'), '%s%s%s'%(module_name, '.', case_dir_name))
         
         tmp = join(os.getcwd(), 'tmp')
-        case_report_dir = _mkdir(join(tmp, '%s%s%s' % (case_dir_name, '@', str(self.conf.case_start_time).replace(' ', '_'))))
+        case_report_dir = _mkdir(join(tmp, '%s%s%s' % (case_dir_name, '@', _wraptime(self.conf.case_start_time).replace(' ', '_'))))
         _writeSSPIDToFile(case_report_dir)
         device.report_dir_path = case_report_dir
 
@@ -331,6 +341,14 @@ class FileOutputPlugin(nose.plugins.Plugin):
             self.conf.update({'case_start_time': case_start_time})
         if self.write_hashes:
             sys.stderr.write('%s%s' % (str(case_start_time), ' '))
+        try:
+            setattr(test, 'failure_image', FAILURE_SNAPSHOT_NAME)
+            setattr(test, 'case_start_time', case_start_time)
+            setattr(test, 'case_pass_dir', self._pass_report_path)
+            setattr(test, 'case_fail_dir', self._fail_report_path)
+            setattr(test, 'case_error_dir', self._error_report_path)
+        except:
+            pass
         
 
     def stopTest(self, test):
@@ -357,7 +375,7 @@ class FileOutputPlugin(nose.plugins.Plugin):
         method_name = test.id().split('.')[-1]
         case_dir_name = '%s%s%s' % (class_name, '.', method_name)
         case_start_time = self.conf.case_start_time
-        case_report_dir_name = '%s%s%s' % (case_dir_name, '@', str(case_start_time).replace(' ', '_'))
+        case_report_dir_name = '%s%s%s' % (case_dir_name, '@', _wraptime(case_start_time).replace(' ', '_'))
         case_report_dir_path = join(self._fail_report_path, case_report_dir_name)
         screenshot_at_failure = None
         log = None
@@ -374,6 +392,8 @@ class FileOutputPlugin(nose.plugins.Plugin):
                 shutil.copyfile(expect, join(dest, expect_snapshot_name))
             except:
                 pass
+            #remove 20160808 
+            print 'failure path', dest
             _save(dest)
             try:
                 shutil.move(dest, self._fail_report_path)
@@ -389,6 +409,8 @@ class FileOutputPlugin(nose.plugins.Plugin):
             tmp = join(os.getcwd(), 'tmp')
             case_report_dir = _mkdir(join(tmp, case_report_dir_name))
             #last step snapshot
+            #remove 20160808
+            print 'failure path', case_report_dir
             _save(case_report_dir)
             try:
                 shutil.move(case_report_dir, self._fail_report_path)
@@ -415,7 +437,7 @@ class FileOutputPlugin(nose.plugins.Plugin):
         method_name = test.id().split('.')[-1]
         case_dir_name = '%s%s%s' % (class_name, '.', method_name)
         case_start_time = self.conf.case_start_time
-        case_report_dir_name = '%s%s%s' % (case_dir_name, '@', str(case_start_time).replace(' ', '_'))
+        case_report_dir_name = '%s%s%s' % (case_dir_name, '@', _wraptime(case_start_time).replace(' ', '_'))
         case_report_dir_path = join(self._error_report_path, case_report_dir_name)
 
         screenshot_at_failure = None
@@ -433,6 +455,7 @@ class FileOutputPlugin(nose.plugins.Plugin):
                 shutil.copyfile(expect, join(dest, expect_snapshot_name))
             except:
                 pass
+            #remove 20160808 
             _save(dest)
             try:
                 shutil.move(dest, self._error_report_path)
@@ -448,6 +471,7 @@ class FileOutputPlugin(nose.plugins.Plugin):
             tmp = join(os.getcwd(), 'tmp')
             case_report_dir = _mkdir(join(tmp, case_report_dir_name))
             #last step snapshot
+            #remove 20160808 
             _save(case_report_dir)
             try:
                 shutil.move(case_report_dir, self._error_report_path)
@@ -511,12 +535,13 @@ class FileOutputPlugin(nose.plugins.Plugin):
         case_dir_name = '%s%s%s' % (class_name, '.', method_name)
         #add 20140925
         case_start_time = self.conf.case_start_time
-        case_report_dir_name = '%s%s%s' % (case_dir_name, '@', str(case_start_time).replace(' ', '_'))
+        case_report_dir_name = '%s%s%s' % (case_dir_name, '@', _wraptime(case_start_time).replace(' ', '_'))
         case_report_dir_path = join(self._pass_report_path, case_report_dir_name)
         try:
             tmp = join(os.getcwd(), 'tmp')
             case_report_dir = _mkdir(join(tmp, case_report_dir_name))
             #last step snapshot
+            #remove 20160808 
             _save(case_report_dir, 'pass')
         except:
             pass
